@@ -4,14 +4,15 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = 0.01;
+our $VERSION = "0.02";
 
 require 'Mango.pm'; # Bit useless if you don't actually have mango
 use Test::Mock::Mango::FakeData;
 use Test::Mock::Mango::DB;
 use Test::Mock::Mango::Collection;
 
-$Test::Mock::Mango::data = Test::Mock::Mango::FakeData->new;
+$Test::Mock::Mango::data  = Test::Mock::Mango::FakeData->new;
+$Test::Mock::Mango::error = undef;
 
 # If we're running with Test::Spec and in appropriate context
 # then use Test::Spec::Mocks to do our monkey patching.
@@ -26,16 +27,16 @@ else {
 
 1;
 
-__END__
+=encoding utf8
 
-=head1 Title
+=head1 NAME
 
-Test::Mock::Mango
+Test::Mock::Mango - Simple stubbing for Mango to allow unit tests for code that uses it
 
 =for html
 <a href="https://travis-ci.org/necrophonic/test-mock-mango"><img src="https://travis-ci.org/necrophonic/test-mock-mango.png?branch=master"></a>
 
-=head1 Synopsis
+=head1 SYNOPSIS
 
   # Using Test::More
   #
@@ -56,7 +57,7 @@ Test::Mock::Mango
   runtests unless caller;
 
 
-=head1 Description
+=head1 DESCRIPTION
 
 Simple stubbing of mango methods. Methods ignore actual queries being entered and
 simply return the data set in the FakeData object. To run a test you need to set
@@ -64,7 +65,7 @@ up the data you expect back first - this module doesn't test your queries, it al
 you to test around mango calls with known conditions.
 
 
-=head1 Stubbed Methods
+=head1 STUBBED METHODS
 
 The following methods are available on each faked part of the mango. We
 describe here briefly how far each actually simulates the real method.
@@ -113,8 +114,19 @@ Returns full name of the fake collection.
 Naively inserts the given doc(s) onto the end of the current fake collection.
 
 Returns an C<oid> for each inserted document. If an C<_id> is specifiec
-in the inserted doc then it is returned, otherwise a random string is
-returned instead.
+in the inserted doc then it is returned, otherwise a new
+L<Mango::BSON::ObjectID> is returned instead.
+
+=head3 update
+
+Doesn't perform a real update. You should set the data state in
+C<$Test::Mock::Mango::data> before making the call to be what
+you expect after the update.
+
+=head3 remove
+
+Doesn't remove anything.
+
 
 
 =head2 Cursor
@@ -139,4 +151,27 @@ Returns the number of documents in the current fake collection.
 
 Arbitarily returns 'C<2>'
 
+
+=head1 TESTING ERROR STATES
+
+L<Test::Mock::Mango> gives you the ability to simulate errors from your
+mango calls.
+
+Simply set the C<error> var before the call:
+
+  $Test::Mock::Mango::error = 'oh noes!';
+
+The next call will then run in an error state as if a real error has occurred.
+The C<error> var is automatically cleared with the call so you don't need
+to C<undef> it afterwards.
+
+
+=head1 AUTHOR
+
+J Gregory <JGREGORY@CPAN.ORG>
+
+=head1 SEE ALSO
+
+L<Mango>
+
 =cut
